@@ -1,7 +1,7 @@
 /*
  * Copyright(c) 1995-1998 by Gennady B. Sorokopud (gena@NetVision.net.il)
  *
- * This software can be freely redistributed and modified for 
+ * This software can be freely redistributed and modified for
  * non-commercial purposes as long as above copyright
  * message and this permission notice appear in all
  * copies of distributed source code and included as separate file
@@ -17,26 +17,26 @@
  *
  */
 
-/* $Id: choose_folder.h,v 2.4 1998/03/29 16:09:23 gena Exp $
+/* $Id: choose_folder.h,v 1.2 1999/11/06 05:13:39 xfmail Exp $
  */
 #ifndef CHOOSE_FOLDER_H
-#define CHOOSE_FOLDER_H
+    #define CHOOSE_FOLDER_H
 
-#include <fl_edit.h>
-#include <dialogs.h>
+    #include <fl_edit.h>
+    #include <dialogs.h>
 
 extern struct _mail_folder *choose_folder();
 extern struct _mail_folder *pup_choose_folder(FL_FORM *form);
 extern struct _mail_folder *create_folder(char *name, int ftype);
 extern struct _mail_folder *create_subfolder(struct _mail_folder *pfolder, char *name);
-extern void about();
+extern void about(int op);
 extern void help(int chapter);
 typedef void (*addr_dbl_cb)(struct _mail_addr *addr, int type, int data);
-#define TO_TYPE  1
-#define CC_TYPE  2
-#define BCC_TYPE 3
-#define	NN_TYPE  4
-#define	FCC_TYPE 5
+    #define TO_TYPE  1
+    #define CC_TYPE  2
+    #define BCC_TYPE 3
+    #define NN_TYPE  4
+    #define FCC_TYPE 5
 extern struct _mail_addr *addr_book(int *addr_type, addr_dbl_cb callback, int data);
 extern struct _mail_addr *find_alias(char *name);
 extern struct _mail_addr *expand_addr_list(struct _mail_msg *msg, struct _mail_addr *addr);
@@ -56,7 +56,7 @@ extern void rules_conf();
 extern void search_msgs();
 extern void log_win();
 extern void xfm_log_close_fd();
-extern void xfm_log_str();
+extern void xfm_log_str(char * str);
 extern struct _mime_msg *compose_attachment(struct _mime_msg *omime);
 extern void PGP_Timer_Call(FL_OBJECT *obj, long param);
 extern void load_signatures();
