@@ -1,7 +1,7 @@
 /*
  * Copyright(c) 1995-1998 by Gennady B. Sorokopud (gena@NetVision.net.il)
  *
- * This software can be freely redistributed and modified for 
+ * This software can be freely redistributed and modified for
  * non-commercial purposes as long as above copyright
  * message and this permission notice appear in all
  * copies of distributed source code and included as separate file
@@ -17,56 +17,56 @@
  *
  */
 
-/* $Id: umail.h,v 2.17 1998/04/21 14:03:12 gena Exp $
+/* $Id: umail.h,v 1.7 1999/11/07 22:27:58 xfmail Exp $
  */
 
-#ifndef		UMAIL_H
-#define		UMAIL_H
+#ifndef     UMAIL_H
+    #define     UMAIL_H
 
-#ifdef __linux__
-#define __USE_BSD_SIGNAL
-#endif
+    #ifdef __linux__
+        #define __USE_BSD_SIGNAL
+    #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-#ifdef	HAVE_LIMITS_H
-#include <limits.h>
-#endif
-#include <signal.h>
-#if STDC_HEADERS || defined(USE_STDARG)
-#include <stdarg.h>
-#else
-#include <varargs.h>
-#endif
-#ifdef	HAVE_CTYPE_H
-#include <ctype.h>
-#endif
-#ifdef	HAVE_SYS_TIME_H
-#include <sys/time.h>
-#endif
-#include <sys/types.h>
+    #include <stdio.h>
+    #include <stdlib.h>
+    #ifdef  HAVE_LIMITS_H
+        #include <limits.h>
+    #endif
+    #include <signal.h>
+    #if STDC_HEADERS || defined(USE_STDARG)
+        #include <stdarg.h>
+    #else
+        #include <varargs.h>
+    #endif
+    #ifdef  HAVE_CTYPE_H
+        #include <ctype.h>
+    #endif
+    #ifdef  HAVE_SYS_TIME_H
+        #include <sys/time.h>
+    #endif
+    #include <sys/types.h>
 
-#ifdef	HAVE_PWD_H
-#include <pwd.h>
-#endif
+    #ifdef  HAVE_PWD_H
+        #include <pwd.h>
+    #endif
 
-#include <forms.h>
+    #include <forms.h>
 
-#include "version.h"
+    #include "version.h"
 
-#define SLEN		256
-#define PLEN		MAXPATHLEN
+    #define SLEN        256
+    #define PLEN        MAXPATHLEN
 
-#define TIME_DBLCLICK	500000
-#define TIME_DBLCLICK_MIN	150000
+    #define TIME_DBLCLICK   500000
+    #define TIME_DBLCLICK_MIN   150000
 
-#ifndef TRUE
-#define	FALSE		(0)
-#define	TRUE		(!FALSE)
-#endif
+    #ifndef TRUE
+        #define FALSE       (0)
+        #define TRUE        (!FALSE)
+    #endif
 
-#define SHIFT 0x01
-#define CTRL 0x02
+    #define SHIFT 0x01
+    #define CTRL 0x02
 
 extern char conf_name[255];
 extern char sender_name[127];
@@ -85,78 +85,41 @@ extern u_int supress_errors;
 /* debug */
 extern u_int debug;
 
-#define STAT_LEN        0x00
-#define DATE_LEN        0x01
-#define SIZE_LEN        0x02
-#define FROM_LEN        0x03
-#define SUBJ_LEN        0x04
-extern int show_msg[5];
+    #define STAT_LEN        0x00
+    #define DATE_LEN        0x01
+    #define SIZE_LEN        0x02
+    #define FROM_LEN        0x03
+    #define SUBJ_LEN        0x04
+    #define UID_LEN         0x05
+extern int show_msg[6];
 
-#define FOLD_LEN        0x00
-#define FNUM_LEN        0x01
-#define FUNR_LEN        0x02
+    #define FOLD_LEN        0x00
+    #define FNUM_LEN        0x01
+    #define FUNR_LEN        0x02
 extern int show_fld[3];
 
-#define	FLD_DUMMY_CLR	0x00
-#define	FLD_SEARCH_CLR	0x01
-#define	FLD_MARK_CLR	0x02
-#define	FLD_RECENT_CLR	0x03
-#define	FLD_SYSTEM_CLR	0x04
-#define	FLD_IMAP_CLR	0x05
-#define	FLD_CURR_CLR	0x06
-#define	FLD_NORMAL_CLR	0x07
-#define	FLD_NEWS_CLR	0x08
+    #define FLD_DUMMY_CLR   0x00
+    #define FLD_SEARCH_CLR  0x01
+    #define FLD_MARK_CLR    0x02
+    #define FLD_RECENT_CLR  0x03
+    #define FLD_SYSTEM_CLR  0x04
+    #define FLD_IMAP_CLR    0x05
+    #define FLD_CURR_CLR    0x06
+    #define FLD_NORMAL_CLR  0x07
+    #define FLD_NEWS_CLR    0x08
 extern int color_fld[9];
 
-#define	MSG_CURR_CLR	0x00
-#define	MSG_UNREAD_CLR	0x01
-#define	MSG_MARK_CLR	0x02
-#define	MSG_NORMAL_CLR	0x03
-#define	MSG_DELETED_CLR	0x04
+    #define MSG_CURR_CLR    0x00
+    #define MSG_UNREAD_CLR  0x01
+    #define MSG_MARK_CLR    0x02
+    #define MSG_NORMAL_CLR  0x03
+    #define MSG_DELETED_CLR 0x04
 extern int color_msg[5];
 
-/* read ~/.xfdefaults file */
-void read_xfdefaults();
-
-/* save everything to configuration file */
-/* returns -1 on error 0 on success */
-extern int b_savecfg();
-/* load contents of configuration file */
-/* returns -1 on error 0 on success */
-extern int b_loadcfg(char *cfg_file_name);
-/* set special flags for specific variable */
-extern void b_setcfg_flags(char *line, int flags);
-#define DONT_STORE      0x01	/* parameter should not be stored in cfg file */
-#define CF_UNSECURE     0x02 	/* parameter may not be sent in bug report */
-#define	CF_NOTCHANGED	0x04	/* configuration will be considered unchanged */
-				/* even if parameter has been changed */
-/* store configuration in file. If nopwd > 0 skip all unsecure parameters */
-/* returns -1 on error and 0 on success */
-int save_cfg_file(char *file, int nopwd);
-
-/* add/replace line in configuration file */
-/* returns -1 on error 0 on success */
-extern int b_putcfg_str(char *cfg_file_name, char *line, char *contents);
-/* delete line from configuration file */
-/* returns -1 on error 0 on success */
-extern int b_delcfg_str(char *cfg_file_name, char *line);
-/* get line from config file */
-/* returns NULL on error */
-extern char *b_getcfg_str(char *cfg_file_name, char *line, char *def);
-extern char *b_getcfg_str_default(char *cfg_file_name, char *line, char *def, int return_default);
-/* add/replace number in configuration file */
-/* returns -1 on error 0 on success */
-extern int b_putcfg_int(char *cfg_file_name, char *line, int contents);
-/* get number from config file */
-/* returns def on error */
-extern int b_getcfg_int(char *cfg_file_name, char *line, int def);
-extern int b_getcfg_int_default(char *cfg_file_name, char *line, int def, int return_default);
-/* check if varname exists in the configuration file */
-/* returns 1 if yes and 0 if no */
-extern int cfg_exist(char *varname);
-/* checks version of configuration file */
-/* returns 1 if don't match */
-int cfg_check_version();
+    #include "cfgfile.h"
+    #define DONT_STORE      0x01    /* parameter should not be stored in cfg file */
+    #define CF_UNSECURE     0x02    /* parameter may not be sent in bug report */
+    #define CF_NOTCHANGED   0x04    /* configuration will be considered unchanged */
 
 struct _mail_msg *next_msg(int ur, struct _mail_msg *cmsg);
 struct _mail_msg *prev_msg(int ur, struct _mail_msg *cmsg);
@@ -192,15 +155,15 @@ extern FL_FORM *view_form(struct _mail_msg *msg, int view);
 /* control. return 1 if double click and 0 if not */
 extern int double_click(int id1, int id2);
 extern int display_msg (int, const char *, const char *, ...);
-#define MSG_FATAL	0x00	/* fatal error , program will terminate */
-#define MSG_QUEST	0x01	/* ask yes/no question */
-#define MSG_WARN	0x02	/* warning , program will continue */
-#define MSG_STAT	0x04	/* display messages in status bar */
-#define MSG_MSG 	0x05	/* display messages */
-#define	MSG_LOG		0x06	/* message to be displayed in log window */
-#define	MSG_STDERR	0x07	/* print to stderr */
+    #define MSG_FATAL   0x00    /* fatal error , program will terminate */
+    #define MSG_QUEST   0x01    /* ask yes/no question */
+    #define MSG_WARN    0x02    /* warning , program will continue */
+    #define MSG_STAT    0x04    /* display messages in status bar */
+    #define MSG_MSG     0x05    /* display messages */
+    #define MSG_LOG     0x06    /* message to be displayed in log window */
+    #define MSG_STDERR  0x07    /* print to stderr */
 /* modifiers */
-#define	MSG_DEFNO	0x10	/* set focus to "No" (when MSG_QUEST) */
+    #define MSG_DEFNO   0x10    /* set focus to "No" (when MSG_QUEST) */
 
 extern void fl_edit_error(char *fmt, ...);
 /* set cursor of for for to cursor. If cursor = 0 restores default cursor */
@@ -221,8 +184,8 @@ void copy_messages(struct _mail_folder *fld);
 
 extern FL_OBJECT       *inc_timer, *send_timer, *trash_timer, *ttip_timer, *imap_timer, *pgp_timer, *asave_timer, *preview_timer;
 extern FL_OBJECT       *menu_misc;
-#define	TTIP_DELAY	1	/* delay before displaying a tooltip */
-extern	void cb_ttip_timer(FL_OBJECT *obj, long param);
+    #define TTIP_DELAY  1   /* delay before displaying a tooltip */
+extern  void cb_ttip_timer(FL_OBJECT *obj, long param);
 
 /* edit message icon pixmap */
 extern Pixmap icon_MailEdit, icon_MailEdit_sh;
@@ -233,15 +196,15 @@ extern Pixmap icon_ABook, icon_ABook_sh;
 void sig_timers();
 
 /* faces (picons) staff */
-#ifdef FACES
+    #ifdef FACES
 char *xbm_to_face();
 char *get_msg_face(struct _mail_msg *msg);
 void update_faces(struct _mail_msg *msg);
-#endif
+    #endif
 char *find_face(struct _mail_addr *addr, int *ftype);
-#define	FACE_XPM	0x01
-#define	FACE_XBM	0x02
-#define	FACEFIELD	"X-Face"
+    #define FACE_XPM    0x01
+    #define FACE_XBM    0x02
+    #define FACEFIELD   "X-Face"
 
 /* this functions redraws different parts of the main window */
 extern void redraw_folders();
@@ -256,7 +219,7 @@ extern void refresh_msgs();
 extern void refresh_folders();
 
 extern FL_OBJECT *fl_find_last(FL_FORM* form, int find, FL_Coord mx, FL_Coord my);
-extern FL_OBJECT *fl_find_first(FL_FORM* form, int find, FL_Coord mx, FL_Coord my);
+extern "C" FL_OBJECT *fl_find_first(FL_FORM* form, int find, FL_Coord mx, FL_Coord my);
 
 extern void show_button_descr(FL_OBJECT *obj);
 
@@ -274,33 +237,33 @@ char *getmyhostname();
 void update_title();
 void select_found();
 
-extern int ttips;	/* show tooltips */
+extern int ttips;   /* show tooltips */
 /* xforms even handler */
 int post_handler(FL_OBJECT *ob, int event,FL_Coord mx, FL_Coord my, int key, void *xev);
 
 /* address book definitions */
 
-#define	MAX_BOOKS		100
-#define MAX_ADDR_IN_BOOK	1023
-#define	MAX_ADDR_IN_ALIAS	1023
-#define	MAX_ABOOK_NAMELEN	16
+    #define MAX_BOOKS       100
+    #define MAX_ADDR_IN_BOOK    1023
+    #define MAX_ADDR_IN_ALIAS   1023
+    #define MAX_ABOOK_NAMELEN   16
 
 /* address book entry */
 typedef struct _abook_entry {
-struct _mail_addr *addr;	/* addresses */
-struct _abook_entry *next;	/* next entry */
-char	*description;		/* short description */
-u_int	type;			/* type of entry */
-#define	ADDR_SINGLE	0x00	/* single address */
-#define	ADDR_ALIAS	0x01	/* alias entry */
+    struct _mail_addr *addr;    /* addresses */
+    struct _abook_entry *next;  /* next entry */
+    char    *description;       /* short description */
+    u_int   type;           /* type of entry */
+    #define ADDR_SINGLE 0x00    /* single address */
+    #define ADDR_ALIAS  0x01    /* alias entry */
 } abook_entry;
 
 typedef struct _abook {
-struct _abook_entry *entries;	/* address book entries */
-char name[16];			/* address book name */
-u_int	flags;			/* special flags */
-#define	ABOOK_LOCAL	0x00	/* local address book */
-#define	ABOOK_REMOTE	0x01	/* remote address book */
+    struct _abook_entry *entries;   /* address book entries */
+    char name[16];          /* address book name */
+    u_int   flags;          /* special flags */
+    #define ABOOK_LOCAL 0x00    /* local address book */
+    #define ABOOK_REMOTE    0x01    /* remote address book */
 } abook;
 
 extern struct _abook_entry *find_addr(struct _mail_addr *addr);
@@ -308,10 +271,10 @@ extern int save_book();
 extern int load_book(char *name);
 extern struct _abook_entry * add_book(struct _mail_addr *new_addr , int ask);
 
-#ifdef	USE_SOUND
+    #ifdef  USE_SOUND
 extern int play_sound(char *soundfile, int volume);
-#define AUDIO_DEVICE	"/dev/audio"
-#endif
+        #define AUDIO_DEVICE    "/dev/audio"
+    #endif
 
 struct _proc_info;
 
@@ -319,26 +282,26 @@ struct _proc_info;
 typedef void (*child_handle)(struct _proc_info *info);
 
 typedef struct _proc_info {
-int pid;			/* process ID */
-int status;			/* process exit status */
-u_int wait;			/* how to wait for process */
-#define	WAIT_ASYNC	0x00	/* don't wait, call handle at exit */
-#define	WAIT_BG		0x01	/* wait , but make GUI work at the same time */
-#define	WAIT_STOP	0x02	/* wait and stop program execution */
-#define	WAIT_FINISHED	0x08	/* process ended (modifier) */
-child_handle handle;		/* handler function */
-child_handle init;		/* initialization function */
-void *u_data;			/* any user data */
-long ul_data;			/* any user data */
-int ifd,			/* file descriptors for stdin, stdout      */
-    ofd,			/* and stderr */
+    int pid;            /* process ID */
+    int status;         /* process exit status */
+    u_int wait;         /* how to wait for process */
+    #define WAIT_ASYNC  0x00    /* don't wait, call handle at exit */
+    #define WAIT_BG     0x01    /* wait , but make GUI work at the same time */
+    #define WAIT_STOP   0x02    /* wait and stop program execution */
+    #define WAIT_FINISHED   0x08    /* process ended (modifier) */
+    child_handle handle;        /* handler function */
+    child_handle init;      /* initialization function */
+    void *u_data;           /* any user data */
+    long ul_data;           /* any user data */
+    int ifd,            /* file descriptors for stdin, stdout      */
+    ofd,            /* and stderr */
     efd;
-int fd_in[2],			/* communication pipes for stdin, stdout   */
-    fd_out[2],			/* and stderr */
+    int fd_in[2],           /* communication pipes for stdin, stdout   */
+    fd_out[2],          /* and stderr */
     fd_err[2];
 } proc_info;
 
-#define	MAX_CHILDREN	0x0f	/* Can not run more then 15 child processes at the same time */
+    #define MAX_CHILDREN    0x0f    /* Can not run more then 15 child processes at the same time */
 
 /* initialize pinfo */
 void init_pinfo(struct _proc_info *pinfo);
@@ -359,7 +322,7 @@ void close_procs();
 
 char *get_sign_file(struct _mail_msg *msg);
 char *pup_choose_sign(FL_FORM *form);
-extern	FL_FORM	*signform;
+extern  FL_FORM *signform;
 
 void cb_help_button(FL_OBJECT *obj, long param);
 void cb_msg_autosave(FL_OBJECT *obj, long num);
@@ -371,34 +334,34 @@ void msg_text_activate(int active);
 
 /* special xforms defaults */
 typedef struct _xfdef {
-int popfsize, popfstyle, popcursor;
-int popbgcol, popfgcol;
+    int popfsize, popfstyle, popcursor;
+    int popbgcol, popfgcol;
 } xfdef;
 
 extern struct _xfdef xfdefs;
 extern int xofft, yofft;
 extern int readonly;
 
-extern void init_pgpargs();
 /* PGP functions and definitions */
 struct pgpargs {
-  char *passphrase;
-  char *recp;
-  char *userid;
-  struct _mail_msg *msg;
+    char *passphrase;
+    char *recp;
+    char *userid;
+    struct _mail_msg *msg;
 };
+extern void init_pgpargs(struct pgpargs * pargs);
 
 extern int pgp_action(char* inbuf, int mode, struct pgpargs*);
 extern char* input_passphrase();
 extern unsigned long PGP_Lookup_PGPId(const char *name, FL_FORM *form);
-#define ENCODE 1	/* Encode with PGP */
-#define DECODE 2	/* Decode with PGP */
-#define SIGN   4	/* Sign with PGP signature */
-#define VERIFY 8	/* Verify PGP signature */
-#define	EXTKEY 16	/* Extract public key */
-#define	ADDKEY 32	/* Add public key to message */
-#define	VRFYFL 64	/* Verify PGP signature in separate file */
-#define	SIGNFL 128	/* Sign and put signature in separate file */
+    #define ENCODE 1    /* Encode with PGP */
+    #define DECODE 2    /* Decode with PGP */
+    #define SIGN   4    /* Sign with PGP signature */
+    #define VERIFY 8    /* Verify PGP signature */
+    #define EXTKEY 16   /* Extract public key */
+    #define ADDKEY 32   /* Add public key to message */
+    #define VRFYFL 64   /* Verify PGP signature in separate file */
+    #define SIGNFL 128  /* Sign and put signature in separate file */
 
 /* check is file is a PGP message */
 /* returns -1 on error, 0 if it's not a PGP messages */
@@ -422,8 +385,8 @@ extern int pgp_encode_rfc2015(struct _mail_msg *msg, int mode);
 /* PGP sign message according to RFC2015 */
 extern int pgp_sign_rfc2015(struct _mail_msg *msg);
 
-#define	PGP_MAX_TIMER		180	/* limit on "forget passphrase" timer */
-#define	PREVIEW_MAX_TIMER	60	/* limit on "mark read" timer */
+    #define PGP_MAX_TIMER       180 /* limit on "forget passphrase" timer */
+    #define PREVIEW_MAX_TIMER   60  /* limit on "mark read" timer */
 
 /* file viewer */
 int file_view(char *file, struct _proc_info *pinfo);
@@ -433,8 +396,8 @@ char *strcasestr(const char *s, const char *find, int scase);
 void map_form(FL_FORM *form);
 
 void disp_infowindow(void *ptr, int type);
-#define	INFO_MSG	0x00
-#define	INFO_FOLDER	0x01
+    #define INFO_MSG    0x00
+    #define INFO_FOLDER 0x01
 
 int load_rules();
 int save_rules();
@@ -442,10 +405,10 @@ void rule_rename_folder(struct _mail_folder *newfolder, char *oldname);
 struct _mime_mailcap *mcap_select(char *mtype, char *msubtype);
 
 extern int logging;
-#define	LOG_SMTP	0x04
-#define	LOG_NET		0x08
-#define	LOG_ERRORS	0x10
-#define	LOG_NNTP	0x20
+    #define LOG_SMTP    0x04
+    #define LOG_NET     0x08
+    #define LOG_ERRORS  0x10
+    #define LOG_NNTP    0x20
 
 int load_sources();
 int save_sources(char *tmpf);
